﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Ivi.Visa.Interop;
using System.IO;
using System.Xml;
using System.Windows;

namespace DAQ
{
    /// <summary>
    /// Application global settings
    /// Revisions:
    ///     2016-02-24 D.A. added:
    ///         - int MainFreq field - AC power frequency
    ///         - string MeasurementUnit - V or A
    ///         - bool ExtTrigger - indicating trigger source
    ///         - support for 'MainFreq' field in Config.xml
    /// </summary>
    static class Settings
    {
        public static string ConfigFilePath;

        // Ivi.Visa.Interop
        public static ResourceManager rm;
        public static FormattedIO488 Dmm;

        // Connection parameters
        public static string USBconnection;
        public static string EthernetConnection;
        public static string PreferredConnection;

        public static int MainFreq;     // Main AC power frequency

        public static string IDN;               // instrument ID
        public static string MeasurementType;   // CURR / VOLT
        public static string MeasurementUnit;
        public static string MeasurementRange;

        public static string FileName;
        public static StreamWriter FileHandle;
        public static bool newFile = false;    // new file selected

        public static int SampleRate;
        public static int RecTime;

        public static bool Abort = false;   // set to true to abort acquisition

        public static int ChunkSize = 50;   // number of readings at a time

        public static bool ExtTrigger;
        public static bool UpTrigger;

        /// <summary>
        /// Read communication settings from Config.xml
        /// </summary>
        public static void ReadCommunicationSettings()
        {
            XmlReader rdr = null;
            try
            {
                rdr = XmlReader.Create(ConfigFilePath);
            }
            catch
            {
                MessageBox.Show("Configuration file cannot be open. Please reinstall the application.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                Application.Current.Shutdown();
                return;
            }

            try{
                while (!rdr.EOF)
                {
                    rdr.Read();
                    if (rdr.NodeType == XmlNodeType.Element)
                    {
                        switch (rdr.Name)
                        {
                            case "USBconnection":
                                USBconnection = rdr.ReadElementString();
                                break;
                            case "EthernetConnection":
                                EthernetConnection = rdr.ReadElementString();
                                break;
                            case "PreferredConnection":
                                PreferredConnection = rdr.ReadElementString();
                                break;
                            case "MainFreq":
                                MainFreq = Int32.Parse(rdr.ReadElementString());
                                break;
                            default:
                                break;
                        }
                    }
                }
            }
            catch
            {
                MessageBox.Show("Configuration file corrupted. Please reinstall the application.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                Application.Current.Shutdown();
                return;
            }
            finally
            {
                rdr.Close();
            }
        }


        /// <summary>
        /// Write communication settings to Config.xml
        /// </summary>
        public static void WriteCommunicationSettings()
        {
            try
            {
                XmlDocument doc = new XmlDocument();
                doc.Load(ConfigFilePath);
                XmlNode root1 = doc.DocumentElement["USBconnection"];
                root1.FirstChild.InnerText = Settings.USBconnection;
                XmlNode root2 = doc.DocumentElement["EthernetConnection"];
                root2.FirstChild.InnerText = Settings.EthernetConnection;
                XmlNode root3 = doc.DocumentElement["PreferredConnection"];
                root3.FirstChild.InnerText = Settings.PreferredConnection;
                XmlNode root4 = doc.DocumentElement["MainFreq"];
                root4.FirstChild.InnerText = Settings.MainFreq.ToString();
                doc.Save(ConfigFilePath);
            }
            catch
            {
                MessageBox.Show("Unable to write to configuration file. You may need to reinstall the application.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

    }
}
